@@ -9,10 +9,10 @@
 # testing and support for generic AT commads, so use it at your own risk,
 # and without ANY warranty! Have fun.
 #
-# $Id: Modem.pm,v 1.16 2002/06/17 20:26:28 Cosimo Exp $
+# $Id: Modem.pm,v 1.18 2002/09/03 20:03:27 cosimo Exp $
 
 package Device::Modem;
-$VERSION = sprintf '%d.%02d', q$Revision: 1.16 $ =~ /(\d)\.(\d+)/;
+$VERSION = sprintf '%d.%02d', q$Revision: 1.18 $ =~ /(\d)\.(\d+)/;
 
 BEGIN {
 
@@ -147,7 +147,7 @@ sub dial {
 	}
 
 	# Remove all non number chars plus some others allowed
-	$number =~ s/[^0-9,\(\)\*-\s]//g;
+	$number =~ s/[^0-9,\(\)\*\-\s]//g;
 
 	# Dial number and wait for response
 	if( length $number == 1 ) {
@@ -258,6 +258,7 @@ sub S_register {
 		$self->log->write('info', 'storing value ['.$new_value.'] into register S'.$register);
 		$self->atsend( sprintf( 'AT S%02d=%d' . CR, $register, $new_value ) );
 
+
 		$value = ( index( $self->answer, 'OK' ) != -1 ) ? $new_value : undef;
 
 	} else {
@@ -548,7 +549,7 @@ sub answer {
 
 	$time_slice /= 1000;
 
-	$me->log->write('info', 'answer: expecting ['.$expect.'] or timeout ['.$timeout.']' );
+	$me->log->write('info', 'answer: expecting ['.($expect||'').'] or timeout ['.$timeout.']' );
 
 	# Main read cycle
 	my $cycle = 0;
@@ -690,6 +691,26 @@ Device::Modem - Perl extension to talk to modem devices connected via serial por
 Device::Modem class implements basic AT (Hayes) compliant device abstraction. It is meant
 to be inherited by sub classes (as Device::Gsm), which are based on serial connections.
 
+In the `examples' directory, there are some scripts that should work without big problems,
+that you can take as (yea) examples:
+
+=over 4
+
+=item `examples/active.pl'
+
+Tests if modem is alive
+
+=item `examples/dial.pl'
+
+Dials a phone number and display result of call
+
+=item `examples/shell.pl'
+
+(Very) poor man's minicom/hyperterminal utility
+
+=back
+
+
 =head2 REQUIRES
 
 =over 4
@@ -754,6 +775,7 @@ modify it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 Device::SerialPort,
+Device::Gsm,
 Win32::SerialPort,
 perl
 
